#!/usr/bin/env python
# -*- coding: utf-8 -*-


class CONSTANTS:
    SECTION = 'section'
    LOGGING_MODE = 'logging_mode'
    FILE_MAX_BYTES = 'file_max_bytes'
    FILE_BACKUP_COUNT = 'file_backup_count'

